﻿# Créé par Boulanger, le 19/01/2023 en Python 3.4
import matplotlib.pyplot as plt  # Importation de la bibliothèque graphique

# Détermination des positions successives de la voiture
m = 0.500 # masse de la voiture en kg
k = 1*0.50/7.4 # échelle : 1 cm sur la photographie représente k m en réalité
t = [0,0.125,0.25,0.375,0.5,0.625] # dates des positions succéssives de la voiture en s
x = [0,0.8*k,1.9*k,3.4*k,5.2*k,7.4*k] # positions succéssives de la voiture le long du rail en m (Ox)
y = [0,0,0,0,0,0] # le mouvement étant horizontal, les coordonnées selon (Oy) sont nulles
plt.figure('Trajectoire de la voiture') # Titre de la figure
plt.xlabel('x (en m)') # Titre Ox

# Calculs des vecteurs vitesse
vx = [(x[i+1]-x[i-1])/(t[i+1]-t[i-1]) for i in range (1, 5)]  # valeur en m/s
vx.insert(0, 0) # Les vecteurs vitesse ne pouvant être déterminés aux premier et  dernier points, ils sont, par défaut, considérés nuls
vx.insert(5, 0)
vy = [0,0,0,0,0,0] # le mouvement étant horizontal, les coordonnées du vecteur vitesse selon (Oy) sont nulles


# Calculs des vecteurs variation de vitesse
Dvx = [vx[i+1] - vx[i-1] for i in range(2, 4)]  # valeur du vecteur variation de vitesse en m/s
Dvx.insert(0, 0) # Les vecteurs variations de vitesse sont considérés nuls par défaut aux points où ils ne peuvent être calculés
Dvx.insert(1, 0)
Dvx.insert(4, 0)
Dvx.insert(5, 0)
Dvy = [0,0,0,0,0,0] # le mouvement étant horizontal, les coordonnées du vecteur variation de vitesse selon (Oy) sont nulles

# Tracé des vecteurs vitesse et variation de vitesse
plt.scatter(x, y, marker = "x", color = "b")  # On place les positions successives de la voiture
plt.text(x[0], y[0], 'M1') # Légende des points
plt.text(x[1], y[1], 'M2')
plt.text(x[2], y[2], 'M3')
plt.text(x[3], y[3], 'M4')
plt.text(x[4], y[4], 'M5')
plt.text(x[5], y[5], 'M6')
plt.quiver(x, y, vx, vy, units = "dots", color = "r", scale = 0.005)  # Représentation des vecteurs vitesse
plt.quiver(x, y, Dvx, Dvy, units = "dots", color = "g", scale = 0.005)  # Représentation des vecteurs variation de vitesse
plt.show()  # Affichage

# Valeur des vecteurs variation de vitesse
nDvx = [round(Dvx[i], 1) for i in range(2, 4)] # Calcul de la valeur arrondie au dizième
print('Valeur des vecteurs variation de vitesse aux points M3 et M4 en m/s :') # Affichage
print(nDvx)

# Vérification de la formule
F = [m*Dvx[i]/(t[i+1]-t[i-1]) for i in range(2, 4)] # Calcul de la valeur
Ft = [float(int(F[i]*10))/10 for i in range(0,2)] # valeur tronquée au dixième
print('Valeur du vecteur masse fois vecteur variation de vitesse divisé par durée courte aux points M3 et M4 en kg.m/s² :') # Affichage
print(Ft)